using System;

namespace Lab4
{
    public class Libro
    {
        private readonly int _id;
        private string _titolo;
        private string _autore;
        private int _anno;
        private int _copieDisponibili = 1;
        private static int _nextId = 1;

        internal Libro()
            : this(String.Empty, String.Empty, 0)
        {
        }

        public Libro(string titolo, string autore, int anno)
        {
            if (titolo == null)
                throw new ArgumentNullException("titolo");
            if (autore == null)
                throw new ArgumentNullException("autore");
            _id = _nextId++;
            _titolo = titolo;
            _autore = autore;
            _anno = anno;
        }

        [Editable("Identificatore", Width = 30)]
        public int Id
        {
            get { return _id; }
        }

        [Editable("Titolo")]
        public string Titolo
        {
            get { return _titolo; }
            set
            {
                if (value == null)
                    throw new ArgumentNullException("value");
                if (value == String.Empty)
                    throw new ArgumentException("Il titolo del libro  obbligatorio");
                _titolo = value;
            }
        }

        [Editable("Autore")]
        public string Autore
        {
            get { return _autore; }
            set
            {
                if (value == null)
                    throw new ArgumentNullException("value");
                if (value == String.Empty)
                    throw new ArgumentException("L'autore del libro  obbligatorio");
                _autore = value;
            }
        }

        [Editable("Anno", Width = 50)]
        public int Anno
        {
            get { return _anno; }
            set
            {
                _anno = value;
            }
        }

        [Editable("Copie Disponibili", Width = 30)]
        public int CopieDisponibili
        {
            get { return _copieDisponibili; }
            set
            {
                if (value < 0)
                    throw new ArgumentException("Valore del numero di copie errato");
                _copieDisponibili = value;
            }
        }

        [Editable("Disponibile", Width = 40)]
        public bool Disponibile
        {
            get { return _copieDisponibili > 0; }
        }

        public override string ToString()
        {
            return Id.ToString() + " - " + Titolo;
        }
    }
}
