using System;
using System.Xml;

namespace Lab4
{
    public class Logger : IDisposable
    {
        private XmlTextWriter _xmlWriter;

        public Logger(string fileName)
        {
            _xmlWriter = new XmlTextWriter(fileName, System.Text.Encoding.Unicode);
            _xmlWriter.Formatting = Formatting.Indented;
            _xmlWriter.Indentation = 3;
            _xmlWriter.WriteStartDocument();
            _xmlWriter.WriteStartElement("EventiBiblioteca");
        }

        public void TracciaNuovoLibro(Libro libro)
        {
            WriteLog("NuovoLibro", libro);
        }

        public void TracciaNuovaPersona(Persona persona)
        {
            WriteLog("NuovaPersona", persona);
        }

        public void TracciaModificaLibro(Libro libro)
        {
            WriteLog("ModificaLibro", libro);
        }

        public void TracciaModificaPersona(Persona persona)
        {
            WriteLog("ModificaPersona", persona);

        }

        private void WriteLog(string tagName, Libro libro)
        {
            if (libro == null)
                throw new ArgumentNullException("libro");
            _xmlWriter.WriteStartElement(tagName);
            _xmlWriter.WriteAttributeString("id", XmlConvert.ToString(libro.Id));
            _xmlWriter.WriteAttributeString("titolo", libro.Titolo);
            _xmlWriter.WriteAttributeString("copieDisponibili", XmlConvert.ToString(libro.CopieDisponibili));
            _xmlWriter.WriteEndElement();
        }

        private void WriteLog(string tagName, Persona persona)
        {
            if (persona == null)
                throw new ArgumentNullException("persona");
            _xmlWriter.WriteStartElement(tagName);
            _xmlWriter.WriteAttributeString("id", XmlConvert.ToString(persona.Id));
            _xmlWriter.WriteAttributeString("nome", persona.Nome);
            _xmlWriter.WriteEndElement();
        }

        #region IDisposable Members

        public void Dispose()
        {
            if (_xmlWriter != null)
            {
                _xmlWriter.WriteEndElement();
                _xmlWriter.WriteEndDocument();
                _xmlWriter.Close();
                _xmlWriter = null;
            }
        }

        #endregion
    }
}
